diff --git a/web/pgadmin/tools/search_objects/static/js/search_objects_dialog_wrapper.js b/web/pgadmin/tools/search_objects/static/js/search_objects_dialog_wrapper.js
index 0c4a315db..a886b25cb 100644
--- a/web/pgadmin/tools/search_objects/static/js/search_objects_dialog_wrapper.js
+++ b/web/pgadmin/tools/search_objects/static/js/search_objects_dialog_wrapper.js
@@ -6,6 +6,7 @@ import 'select2';
 import {DialogWrapper} from 'sources/alertify/dialog_wrapper';
 import Slick from 'sources/../bundle/slickgrid';
 import pgAdmin from 'sources/pgadmin';
+import _ from 'underscore';
 
 
 export default class SearchObjectsDialogWrapper extends DialogWrapper {
@@ -203,7 +204,7 @@ export default class SearchObjectsDialogWrapper extends DialogWrapper {
       this.searchResult,
       this.dataview,
       [
-        { id: 'name', name: gettext('Object name'), field: 'name', sortable: true,
+        { id: 'name', name: gettext('Object name'), field: 'name', sortable: true, width: 50,
           formatter: (row, cell, value, columnDef, dataContext) => {
             let ret_el = `<i class='wcTabIcon ${dataContext.icon}'></i>${value}`;
 
@@ -213,10 +214,9 @@ export default class SearchObjectsDialogWrapper extends DialogWrapper {
 
             return ret_el;
           },
-          width: 50,
         },
         { id: 'type', name: gettext('Type'), field: 'type_label', sortable: true, width: 35 },
-        { id: 'path', name: gettext('Browser path'), field: 'path', sortable: false },
+        { id: 'path', name: gettext('Browser path'), field: 'path', sortable: false, formatter: (row, cell, value) => value },
       ],
       {
         enableCellNavigation: true,
@@ -356,6 +356,12 @@ export default class SearchObjectsDialogWrapper extends DialogWrapper {
     [datum.path, datum.id_path] = this.translateSearchObjectsPath(datum.path, datum.catalog_level);
     /* id is required by slickgrid dataview */
     datum.id = datum.id_path;
+
+    /* Esacpe XSS */
+    datum.name = _.escape(datum.name);
+    datum.path = _.escape(datum.path);
+    datum.other_info = datum.other_info ? _.escape(datum.other_info) : datum.other_info;
+
     return datum;
   }
 
diff --git a/web/pgadmin/tools/search_objects/utils.py b/web/pgadmin/tools/search_objects/utils.py
index cf858d6e2..a3c3d5ac9 100644
--- a/web/pgadmin/tools/search_objects/utils.py
+++ b/web/pgadmin/tools/search_objects/utils.py
@@ -102,6 +102,9 @@ class SearchObjectsHelper:
 
         show_node_prefs = self.get_show_node_prefs()
         node_labels = self.get_supported_types(skip_check=True)
+        # escape the single quote from search text
+        text = text.replace("'", "''")
+
         # Column catalog_level has values as
         # N - Not a catalog schema
         # D - Catalog schema with DB support - pg_catalog
diff --git a/web/regression/javascript/search_objects/search_objects_dialog_wrapper_spec.js b/web/regression/javascript/search_objects/search_objects_dialog_wrapper_spec.js
index e3c698bb8..20244b4ab 100644
--- a/web/regression/javascript/search_objects/search_objects_dialog_wrapper_spec.js
+++ b/web/regression/javascript/search_objects/search_objects_dialog_wrapper_spec.js
@@ -428,6 +428,7 @@ describe('SearchObjectsDialogWrapper', () => {
         type_label: 'Some types coll',
         path: ':some.123:/path',
         show_node: true,
+        other_info: null,
       });
       expect(data).toEqual({
         id: 'id/path',
@@ -438,6 +439,7 @@ describe('SearchObjectsDialogWrapper', () => {
         path: 'disp/path',
         id_path: 'id/path',
         show_node: true,
+        other_info: null,
       });
     });
 
